<link rel="stylesheet" href="/static/css/main.css">
<link rel="stylesheet" href="/static/css/font-awesome.min.css">

<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
<!------ Include the above in your HEAD tag ---------->

<!DOCTYPE html>
<html>
	<head>
		<title>Messaging App</title>
	</head>
	<body>
            
        <div class="chat">
          {% block content %}{% endblock %}
        </div>
	</body>
    {% block script %}{% endblock %}
  <script>
    	$(document).ready(function(){
        $("#user-list-col").load("/user-list");
      });

    </script>
</html>
