{% extends 'base.html' %}
{% block content %}	

<div class="sidebar" id="user-list-col">
                        
</div>

<div class="content">
	<div id="messages-div" style="flex: 1; display: flex; flex-direction: column;">

	</div>
	<div class="message-send">
		<form action = "/new-message" method = "post" style="display: flex; flex: 1;">
			<input type="hidden" id="user" name="user" value="{{user_id}}">
			<input id="text" name="text" type="text" placeholder="Bir şeyler yaz.." style="margin: 0 5px;">
			<button type="submit" class="send-btn" style="margin: 0 5px;">
				<i class="fa fa-paper-plane"></i>
			</button>
		  </form>

	</div>
</div>
			
					{% endblock %}

					{% block script %}
					<script>
					$(document).ready(function(){
						$("#messages-div").load("/get-messages/{{user_id}}");
					});				
					</script>
					{% endblock %}
