

		
					

        <div class="message-header">
            <img src="/static/image/cool-emoji.png" alt="">
            <div class="inner">
                <div class="name">{{user["name"]}}</div>
                <div class="last-message">15dk önce</div>
            </div>
        </div>



       


        <div class="message-content">
            {% for message in messages: %}
            {% if messages[message]["from"] == "me": %}
            <div class="message me">
                <div class="bubble">
                    {{messages[message]["message"]}}
                </div>
                <div class="time">16dk önce</div>
            </div>
            {% else %}
            <div class="message">
                <div class="bubble">
                    {{messages[message]["message"]}}
                </div>
                <div class="time">1dk önce</div>
            </div>
            {% endif %}
    
            {% endfor %}

        </div>









