* {
	padding: 0;
	margin: 0;
	font-family: "Inter-Bold", "Inter", sans-serif;
	box-sizing: border-box;
	outline: 0;
	text-decoration: none;
}

html, body {
	height: 100%;
}

.chat {
	display: flex;
	height: 100%;
}

.chat .sidebar {
    width: 300px;
    background: #f5f5f5;
    border-right: 1px solid #ddd;
    display: flex;
    flex-direction: column;

}

.chat .sidebar .search {
    height: 50px;
    min-height: 50px;
    display: flex;
    align-items: center;
    padding: 0 10px;
    position: relative;
    border-bottom: 1px solid #ddd;
}
.chat .sidebar .search input {
    width: 100%;
    border: none;
    height: 30px;
    border-radius: 30px;
    padding: 0 15px;
    line-height: 30px;
    font-size: 15px;
}
.chat .sidebar .search label {
    position: absolute;
    top: 0;
    right: 0;
    width: 40px;
    height: 50px;
    display: flex;
    align-items: center;
    font-size: 14px;
    color: rgba(#000, .5);
}

.chat .sidebar .contacts {
    background: #f8f8f8;
    overflow: auto;

}
.chat .sidebar .contacts ul li {
        &.active a {
            background: #dddddd;
        }
    }
.chat .sidebar .contacts ul li a {
        display: flex;
        padding: 10px;
        align-items: center;
        &:hover {
            background: #808080;
        }
    }
.chat .sidebar .contacts ul li a img {
        width: 40px;
        height: 40px;
        border-radius: 50%;
        align-items: center;
        margin-right: 10px;
    }


.chat .sidebar .contacts ul li a .inner .name {
        font-weight: 500;
        color: #111;
        font-size: 15px;
    }
.chat .sidebar .contacts ul li a .inner .message {
        font-size: 13px;
        color: #000000a1;
        padding-top: 3px;
    }
.chat .sidebar .contacts ul li a .notification {
        margin-left: auto;
        width: 18px;
        height: 18px;
        background: red;
        color: #fff;
        font-size: 11px;
        border-radius: 50%;
        text-align: center;
        line-height: 18px;
    }
.chat .sidebar .contacts ul li a .notification:empty {
        display: none;
    }
.chat .content {
    flex: 1;
    display: flex;
    flex-direction: column;
}

.chat .content .message-header {
    display: flex;
    height: 50px;
    min-height: 50px;
    align-items: center;
    padding: 0 15px;
    border-bottom: 1px solid #ddd;


}

.chat .content .message-header img {
    height: 35px;
    border-radius: 50%;
    margin-right: 10px;
}

.chat .content .message-header .inner .name {
    font-size: 15px;
    font-weight: 600;
    color: #111;
}
.chat .content .message-header .inner .last-message {
    font-size: 12px;
    color: rgba(#000,.4);
}

.chat .content .message-header .actions {
    margin-left: auto;
    display: flex;

}

.chat .content .message-header .actions a {
    font-size: 20px;
    color: rgba(#111, .3);
    width: 30px;
    text-align: center;

}
.chat .content .message-header .actions a:hover {
    color: rgba(#111, .7);
}


.chat .content .message-content {
    flex: 1;
    padding: 15px;
    display: flex;
    flex-direction: column;
    overflow: auto;

}


.chat .content .message-content::before {
    content: '';
    margin-bottom: auto;
}

.chat .content .message-content .message {
    display: flex;
    margin-top: 15px;
    flex-direction: column;
    align-self: flex-start;
    max-width: 50%;


}
.chat .content .message-content .message .bubble {
    background: #f7f7f7;
    padding: 6px 15px;
    border-radius: 20px;
    font-size: 14px;
    line-height: 140%;
}

.chat .content .message-content .message .time {
    font-size: 12px;
    color: rgba(#000, .4);
    padding: 5px 0 0 10px;
}

.chat .content .message-content .message.me {
    align-self: flex-end;
}

.chat .content .message-content .message.me .bubble {
    background: #2196f3;
    color: #fff;
}

.chat .content .message-content .message.me .time {
    align-self: flex-end;
    padding-right: 5px;
}


.chat .content .message-send {
    display: flex;
    padding: 10px 5px;
    border-top: 1px solid #ddd;
}




.chat .content .message-send >* {
    margin: 0 5px;
}

.chat .content .message-send input {
    flex: 1;
    border: 1px solid #e5e5e5;
    height: 36px;
    border-radius: 36px;
    line-height: 36px;
    padding: 0 10px;
    font-size: 14px;
}

.chat .content .message-send button {
    width: 36px;
    min-width: 36px;
    height: 36px;
    border-radius: 50%;
    font-size: 16px;
    border: none;
    background: #f5f5f5;
    cursor: pointer;
    color: #fff;


}

.chat .content .message-send button.emoji-btn {
    background: #339af0;
}

.chat .content .message-send button.send-btn {
    background: #339af0;
}

.chat .content .message-send button.sound-btn {
    background: #ff5722;
}

.chat .content .message-send button.image-btn {
    background: #4caf50;
}

.add_new_user_button {
    width: 30px;
    min-width: 30px;
    height: 30px;
    border-radius: 50%;
    font-size: 16px;
    border: none;
    background: #339af0;
    cursor: pointer;
    color: #fff;

}